-- About GoogleScholarSearchChromium.lua
--
-- GoogleScholarSearchChromium.lua does a Google Scholar search for the PhotoArticleTitle for articles in ILLiad or ArticleTitle in Ares.
-- autoSearch (boolean) determines whether the search is performed automatically when a request is opened or not.

local settings = {};
settings.AutoSearch = GetSetting("AutoSearch");

local interfaceMngr = nil;
local googleSearchForm = {};
googleSearchForm.Form = nil;
googleSearchForm.Browser = nil;
googleSearchForm.RibbonPage = nil;

luanet.load_assembly("System");
luanet.load_assembly("System.Windows.Forms");
Types = {};
Types["System.Diagnostics.Process"] = luanet.import_type("System.Diagnostics.Process");
Types["System.Windows.Forms.Application"] = luanet.import_type("System.Windows.Forms.Application");

function Init()
	if IsEnabled() then
		interfaceMngr = GetInterfaceManager();
		
		-- Create a form
		googleSearchForm.Form = interfaceMngr:CreateForm("Google Scholar Search", "Script");

		local browserType;
		if AddonInfo.Browsers and AddonInfo.Browsers.WebView2 and AddonInfo.Browsers.WebView2 then
			browserType = "WebView2";
		else
			browserType = "Chromium";
		end
		
		-- Add a browser
		googleSearchForm.Browser = googleSearchForm.Form:CreateBrowser("Google Scholar Search", "Google Scholar Search Browser", "Google Scholar Search", browserType);
		
		-- Hide the text label
		googleSearchForm.Browser.TextVisible = false;
		
		-- Since we didn't create a ribbon explicitly before creating our browser, it will have created one using the name we passed the CreateBrowser method.  We can retrieve that one and add our buttons to it.
		googleSearchForm.RibbonPage = googleSearchForm.Form:GetRibbonPage("Google Scholar Search");
		
		-- Create the search button
		googleSearchForm.RibbonPage:CreateButton("Search", GetClientImage("Search32"), "Search", "Google Scholar");
		googleSearchForm.RibbonPage:CreateButton("Open in New Window", GetClientImage("OpenBrowser32"), "OpenInNewWindow", "Google Scholar");
		
		-- After we add all of our buttons and form elements, we can show the form.
		googleSearchForm.Form:Show();
		
		googleSearchForm.Form:LoadLayout("layout.xml");

		if settings.AutoSearch then
			Search();
		end
	end
end

function IsEnabled()
	local productName = Types["System.Windows.Forms.Application"].ProductName;
	local enabled = (((productName == "ILLiad") and (GetFieldValue("Transaction", "RequestType") == "Article"))
		or ((productName == "Ares") and (GetFieldValue("Item", "ItemType") == "SER")));

	if (not enabled) then
		LogDebug("Addon not applicable to this product or request/item type. Cancelling initialization.");
	end

	return enabled;

end

function Search()
	local productName = Types["System.Windows.Forms.Application"].ProductName;
	local searchTerm = "";
	
	if productName == "Ares" then
		searchTerm = GetFieldValue("Item", "ArticleTitle") or "";
	elseif productName == "ILLiad" then
		searchTerm = GetFieldValue("Transaction", "PhotoArticleTitle") or "";
	end

	googleSearchForm.Browser:Navigate("http://scholar.google.com/scholar?q=" .. UrlEncode(searchTerm));	
end

function OpenInNewWindow()
	local currentUrl = googleSearchForm.Browser.Address;
	
	if currentUrl and currentUrl ~= "" then
		LogDebug("Opening " .. currentUrl .. " in default browser window.");

		local process = Types["System.Diagnostics.Process"]();
		process.StartInfo.FileName = currentUrl;
		process.StartInfo.UseShellExecute = true;
		process:Start();
	end
end

function UrlEncode(s)
	if (s) then
		s = string.gsub(s, "\n", "\r\n")
		s = string.gsub(s, "([^%w %-%_%.%~])",
			function (c)
				return string.format("%%%02X", string.byte(c))
			end);
		s = string.gsub(s, " ", "+")
	end
	return s
end