-- About GoogleScholarSearchChromium.lua
--
-- GoogleScholarSearchChromium.lua does a Google Scholar search for the PhotoArticleTitle for articles in ILLiad or ArticleTitle in Ares.
-- autoSearch (boolean) determines whether the search is performed automatically when a request is opened or not.

local settings = {};
settings.AutoSearch = GetSetting("AutoSearch");

local interfaceMngr = nil;
local googleSearchForm = {};
googleSearchForm.Form = nil;
googleSearchForm.Browser = nil;
googleSearchForm.RibbonPage = nil;

luanet.load_assembly("System.Windows.Forms");
local Application = luanet.import_type("System.Windows.Forms.Application");

function Init()
	if IsEnabled() then
		interfaceMngr = GetInterfaceManager();
		
		-- Create a form
		googleSearchForm.Form = interfaceMngr:CreateForm("Google Scholar Search", "Script");
		
		-- Add a browser
		googleSearchForm.Browser = googleSearchForm.Form:CreateBrowser("Google Scholar Search", "Google Scholar Search Browser", "Google Scholar Search", "Chromium");
		
		-- Hide the text label
		googleSearchForm.Browser.TextVisible = false;
		
		-- Since we didn't create a ribbon explicitly before creating our browser, it will have created one using the name we passed the CreateBrowser method.  We can retrieve that one and add our buttons to it.
		googleSearchForm.RibbonPage = googleSearchForm.Form:GetRibbonPage("Google Scholar Search");
		
		-- Create the search button
		googleSearchForm.RibbonPage:CreateButton("Search", GetClientImage("Search32"), "Search", "Google Scholar");
		
		-- After we add all of our buttons and form elements, we can show the form.
		googleSearchForm.Form:Show();
		
		googleSearchForm.Form:LoadLayout("layout.xml");

		if settings.AutoSearch then
			Search();
		end
	end
end

function IsEnabled()
	
	local enabled = (((Application.ProductName == "ILLiad") and (GetFieldValue("Transaction", "RequestType") == "Article"))
		or ((Application.ProductName == "Ares") and (GetFieldValue("Item", "ItemType") == "SER")));

	if (not enabled) then
		LogDebug("Addon not applicable to this product or request/item type. Cancelling initialization.");
	end

	return enabled;

end

function Search()

	local searchTerm = "";
	
	if Application.ProductName == "Ares" then
		searchTerm = GetFieldValue("Item", "ArticleTitle") or "";
	elseif Application.ProductName == "ILLiad" then
		searchTerm = GetFieldValue("Transaction", "PhotoArticleTitle") or "";
	end

	googleSearchForm.Browser:Navigate("http://scholar.google.com/scholar?q=" .. UrlEncode(searchTerm));	
end

function UrlEncode(s)
	if (s) then
		s = string.gsub(s, "\n", "\r\n")
		s = string.gsub(s, "([^%w %-%_%.%~])",
			function (c)
				return string.format("%%%02X", string.byte(c))
			end);
		s = string.gsub(s, " ", "+")
	end
	return s
end